Trussed
Trussed® is a minimal, modular way to write cryptographic applications on microcontroller platforms. Easy to write, easy to audit — compile-time security by default.
Documentation is evolving, a good entry point is the module trussed::client.
Re-exports
Modules
- backend
- Custom backends that can override core request implementations.
- config
- key
- pipe
- platform
- Trait for platforms to implement that use Trussed.
- serde_
extensions serde-extensions - Extensions to the core Trussed syscalls.
- service
- store
storepresents a combined interface to three littlefs2 filesystems: internal flash, external flash, volatile/RAM.- types
- virt
virt - Trussed platform implemented in software with RAM storage FOR TESTING ONLY
Macros
Structs
- Client
Implementation - The client implementation client applications actually receive.
- Interchange
- Set of
Nchannels
Traits
- Client
all-clients - All-in-one trait bounding on the sub-traits.