Trait for platforms to implement that use Trussed.
Trussed requires access to a cryptographically secure random number generator, facilities for persistent and volatile storage, and some user interface to ensure operations do not happen without user consent. Implementing this trait enables this.
TODO: Currently, Platform::R lacks the CryptoRng bound.
Re-exports
pub use crate::store::Store;pub use crate::types::ui;pub use crate::types::reboot;pub use crate::types::consent;
Traits
- Crypto
Rng - A marker trait used to indicate that an
RngCoreorBlockRngCoreimplementation is supposed to be cryptographically secure. - Platform
- RngCore
- The core of a random number generator.
- Syscall
- Trussed client will call this method when making a Trussed request. This is intended to trigger a secure context on the platform.
- User
Interface